@@ -1,6 +1,6 @@
 /* --------------------------------------------------------------------------
  * core of haserl.cgi - a poor-man's php for embedded/lightweight environments
- * Copyright (c) 2003-2007   Nathan Angelacos (nangel@users.sourceforge.net)
+ * Copyright (c) 2003-2011   Nathan Angelacos (nangel@users.sourceforge.net)
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2, as published by the Free
@@ -397,17 +397,17 @@ haserlflags (list_t * env)
 {
   char buf[200];
 
-  snprintf (buf, 200, "HASERL_UPLOAD_DIR=%s", global.uploaddir);
-  myputenv (env, buf, global.nul_prefix);
+  snprintf (buf, 200, "UPLOAD_DIR=%s", global.uploaddir);
+  myputenv (env, buf, global.haserl_prefix);
 
-  snprintf (buf, 200, "HASERL_UPLOAD_LIMIT=%lu", global.uploadkb);
-  myputenv (env, buf, global.nul_prefix);
+  snprintf (buf, 200, "UPLOAD_LIMIT=%lu", global.uploadkb);
+  myputenv (env, buf, global.haserl_prefix);
 
-  snprintf (buf, 200, "HASERL_ACCEPT_ALL=%d", global.acceptall);
-  myputenv (env, buf, global.nul_prefix);
+  snprintf (buf, 200, "ACCEPT_ALL=%d", global.acceptall);
+  myputenv (env, buf, global.haserl_prefix);
 
-  snprintf (buf, 200, "HASERL_SHELL=%s", global.shell);
-  myputenv (env, buf, global.nul_prefix);
+  snprintf (buf, 200, "SHELL=%s", global.shell);
+  myputenv (env, buf, global.haserl_prefix);
 
 }
 
@@ -644,6 +644,7 @@ assignGlobalStartupValues ()
   global.get_prefix = "GET_";
   global.post_prefix = "POST_";
   global.cookie_prefix = "COOKIE_";
+  global.haserl_prefix = "HASERL_";
   global.nul_prefix = "";
 
 }
@@ -819,7 +820,10 @@ main (int argc, char *argv[])
       shell_destroy = &lua_common_destroy;
       global.var_prefix = "FORM.";
       global.nul_prefix = "ENV.";
-
+      global.get_prefix = "GET.";
+      global.post_prefix = "POST.";
+      global.cookie_prefix = "COOKIE.";
+      global.haserl_prefix = "HASERL.";
       if (global.shell[3] == 'c')	/* luac only */
 #ifdef INCLUDE_LUACSHELL
 	shell_doscript = &luac_doscript;
