@@ -180,7 +180,9 @@ mime_var_putenv (list_t * env, mime_var_t * obj)
       buffer_add (&buf, "_path=", 6);
       buffer_add (&buf, (char *) obj->value.data,
 		  strlen ((char *) obj->value.data) + 1);
-      myputenv (env, (char *) buf.data, "HASERL_");
+      myputenv (env, (char *) buf.data, global.haserl_prefix);
+      myputenv (env, (char *) buf.data, global.var_prefix);
+      myputenv (env, (char *) buf.data, global.post_prefix);
       buffer_reset (&buf);
 
       /* this saves the name of the file the client supplied */
